@@ -71,6 +71,9 @@ void window_cmd_stop                            (GSimpleAction *action,
 void window_cmd_reload                          (GSimpleAction *action,
                                                  GVariant      *parameter,
                                                  gpointer       user_data);
+void window_cmd_reload_bypass_cache             (GSimpleAction *action,
+                                                 GVariant      *parameter,
+                                                 gpointer       user_data);
 void window_cmd_combined_stop_reload            (GSimpleAction *action,
                                                  GVariant      *parameter,
                                                  gpointer       user_data);
@@ -215,5 +218,8 @@ void window_cmd_open_application_manager        (GSimpleAction *action,
 void window_cmd_homepage_new_tab                (GSimpleAction *action,
                                                  GVariant      *parameter,
                                                  gpointer       user_data);
+void window_cmd_new_tab_from_clipboard          (GSimpleAction *action,
+                                                 GVariant      *parameter,
+                                                 gpointer       user_data);
 
 G_END_DECLS
